@@ -1,6 +1,7 @@
 import requests
 from requests.auth import HTTPBasicAuth
 import json
+import statistics
 
 class oe_api():
 
@@ -88,7 +89,6 @@ class oe_api():
         start=self.convert_datetime_to_tz(start)
         end=self.convert_datetime_to_tz(end)
 
-        url=self.base
         setup=f"/electricity-meter-points/{self.mpan}/meters/{self.serial_number}/consumption/"
         
         parameters=f"?page_size=10000&period_from={start}&period_to={end}&order_by=period"
@@ -98,3 +98,54 @@ class oe_api():
         response = self._get(url)
 
         return(response['results'])
+
+    def consumption_total(self, start, end):
+        """Calculates the amount of kWh used in the timeframe given, returns the value as a float"""
+
+        consumption=self.consumption(start, end)
+
+        total_consumption = 0
+
+        for record in consumption:
+            total_consumption+=record['consumption']
+        
+        total_consumption = float('%.2f' % total_consumption)
+        
+        return(total_consumption)
+    
+    def consumption_mean(self, start, end):
+        """Calculates the average kWh used in 30 minutes within the timeframe given, returns the value as a float"""
+
+        consumption=self.consumption(start, end)
+
+        consumption_list = []
+
+        for record in consumption:
+            consumption_list.append(record['consumption'])
+        
+        average = float('%.2f' % float(sum(consumption_list) / len(consumption_list)))
+        
+        return(average)
+
+    def consumption_median(self, start, end):
+
+        consumption=self.consumption(start, end)
+
+        consumption_list = []
+
+        for record in consumption:
+            consumption_list.append(record['consumption'])
+
+        median = statistics.median(consumption_list)
+
+        return(median)
+
+    def meter_point(self):
+
+        setup=f"/electricity-meter-points/{self.mpan}/"
+
+        url=f"{self.base}{setup}"
+
+        response = self._get(url)
+
+        return(response)
\ No newline at end of file
